<?php


namespace app\cbcrm\controller;


use app\BaseController;
use app\cbcrm\model\admin\site\FriendLinkModel;
use app\cbcrm\model\admin\site\MenuModel;
use app\cbcrm\model\admin\store\ConfigModel;
use app\cbcrm\model\article\BlockModel;
use app\cbcrm\model\config\SettingModel;
use app\cbcrm\model\goods\CategoryModel;
use app\cbcrm\model\member\MemberModel;
use think\App;
use think\exception\HttpResponseException;
use think\facade\Cache;
use think\facade\Cookie;
use think\facade\Db;
use think\facade\Session;
use think\facade\View;
use think\Request;
use think\Response;

class BaseSite extends BaseController
{
    use \liliuwei\think\Jump;

    protected $wid;

    protected $isHome = false;

    protected $__CDN__ = '/app/cbcrm/site';

    protected $expire_time = 604800; // 过期时间 7天

    protected $auth = null;

    public function __construct(App $app)
    {
        parent::__construct($app);

        if ($this->request->controller() == 'site.Index') {
            $this->isHome = true;
        };

        $this->request->filter('strip_tags,htmlentities,htmlspecialchars');

        // 首先根据默认站点获取商户ID
        $this->wid = (new ConfigModel())->where('is_default', 1)->value('wid');

        // 其次根据域名站点获取商户ID
        $domain = $this->request->host();

        $domainWid = (new SettingModel())->where('name','domain')->where('group','pc')->where('value',$domain)->value('wid');

        if ($domainWid) {
            $this->wid = $domainWid;
        }
        // 最后根据切换的城市站点获取商户ID
        $cityWid = Cookie::get('wid');
        $city = [];
        if($cityWid){
          $hasStore = Db::table('kt_base_user_openapp')->where('wid',$cityWid)->where('code','cbcrm')->value('wid');
          if($hasStore){
            $this->wid = $cityWid;
          }
          $city = Cookie::get('city');
          $city = $city?json_decode(base64_decode($city),true):[];
        }

        if ($this->request->isMobile()) {
           header('Location:'.$this->request->domain().'/cbcrm/web/wid/'.$this->wid.'#/');
        }

        $menuWhere = [
            'status'=>1,
        ];
        if ($this->wid) {
            $menuWhere['wid'] = $this->wid;
        }else{
            $menuWhere['wid'] = 0;
        }

        // 获取导航菜单
        $menuList = (new MenuModel())->where($menuWhere)->order('sort', 'desc')->order('id', 'desc')->select()->toArray();
        if (!$menuList) {
            $menuWhere['wid'] = 0;
            $menuList = (new MenuModel())->where($menuWhere)->order('sort', 'desc')->order('id', 'desc')->select();
        }

        // 商品服务分类
        $categoryData = (new CategoryModel())->getList($this->wid);

        // 站点配置
        $configData = (new SettingModel())->getDetail('pc',$this->wid);

        // 友情链接
        $friendLink = (new FriendLinkModel())->where('wid',$this->wid)->where('status',1)->order('sort desc,id asc')->cache('friendlnik')->select();

        // 广告
        $blockModel = new BlockModel();
        $blockData = [];
        $blockList = $blockModel->where('status',1)->where('wid',$this->wid)->order('sort desc,id asc')->select()->toArray();
        foreach($blockList as $key=>$block){
            $block['content'] = strip_tags($block['content']);
            if(isset($blockData[$block['type']])){
                $blockData[$block['type']][] = $block;
            }else{
                $blockData[$block['type']] = [$block];
            }
        }

        // 商标分类
        $tmClasses = Cache::get('tmClasses');
        if(!$tmClasses){
            $tmClasses = file_get_contents($this->request->domain().$this->__CDN__.'/js/tm-classes-alias.js');
            $tmClasses = json_decode(trim(ltrim($tmClasses,'module.exports ='),';'),JSON_UNESCAPED_UNICODE);
            $temp = [];
            foreach ($tmClasses as $key=>$class) {
                $temp[] = [
                    'id'=>$key,
                    'name'=>$class
                ];
            }
            $tmClasses = $temp;
            Cache::set('tmClasses',$tmClasses);
        }

        View::assign(compact('menuList', 'categoryData','blockData','friendLink','configData','city','tmClasses'));

        View::assign('__CDN__', $this->__CDN__);

        View::assign('wid', $this->wid);

        View::assign('token', session('memberToken'));

        View::assign('userInfo', session('memberInfo'));

        View::assign('isHome', $this->isHome);
    }

    protected function auth()
    {
        $userInfo = session('memberInfo');
        if ($userInfo) {
            $user = (new MemberModel())->where('id',$userInfo['id'])->find();
            unset($user->password,$user->salt);
            if ($user) {
                $userInfo = $user;
            }else{
                $this->error('请先登录',null,'/cbcrm/login.html');
            }
        }else{
            $this->error('请先登录',null,'/cbcrm/login.html');
        }
        return $userInfo;
    }
}
