<?php


namespace app\cbcrm\controller\site;


use app\cbcrm\controller\BaseSite;
use app\cbcrm\model\config\SettingModel;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;
use think\App;
use think\Exception;
use think\facade\View;
use think\Request;

class TmTradeLib extends BaseSite
{
    protected $apiUrl = 'http://haoip.tunke.cn/api';

    protected $api_key = '';

    protected $trade_money_ratio = 0;

    public function __construct(App $app)
    {
        parent::__construct($app);

        $this->api_key = (new SettingModel())->getConfigValue('trade', 'trade_key', $this->wid);

        $this->trade_money_ratio = (new SettingModel())->getConfigValue('trade', 'trade_money_ratio', $this->wid);
    }

    public function index()
    {
        if ($this->request->isAjax()) {
            $page = \request()->get('page', 1, 'intval');
            $search_type = \request()->get('search_type');
            $search = \request()->get('search', '', 'strip_tags,trim,htmlspecialchars');
            $cls = \request()->get('cls', -1);
            $type = \request()->get('type','');
            $price = \request()->get('price','');
            $trademark_length = \request()->get('trademark_length', '');
            $params = [
                'api_key' => $this->api_key,
                'page' => $page,
                'status' => 1,
                'trade_status' => 0,
                'admin_status' => 1,
                'limit' => 40
            ];
            if ($search) {
                $params['search_type'] = $search_type;
                $params['search'] = $search;
            }
            if ($cls > -1) {
                $params['cls'] = $cls;
            }
            if ($trademark_length) {
                $params['trademark_length'] = $trademark_length;
            }
            if ($type) {
                $params['type'] = $type;
            }
            if ($price) {
                // 0-9999
                $priceArr = explode('-',$price);
                if (count($priceArr) > 1) {
                    if ($priceArr[0] > $priceArr[1]) {
                        $this->error('最大金额必须大于最小金额');
                    }
                    if ($this->trade_money_ratio) {
                        if ($priceArr[0] > 0) {
                            $priceArr[0] =  round($priceArr[0] / (1+($this->trade_money_ratio / 100)));
                        }
                        $priceArr[1] = round($priceArr[1] / (1+($this->trade_money_ratio / 100)));
                        $price = implode('-',$priceArr);
                    }
                }
                $params['price'] = $price;
            }
            $data = [
                'current_page' => 1,
                'data' => [],
                'last_page' => 1,
                'per_page' => 1,
                'total' => 0,
            ];
            $client = new Client();
            try {
                $response = $client->request('GET', $this->apiUrl . '/trade/trademark/getCloudList', [
                    'query' => $params
                ]);
                $result = json_decode($response->getBody(), true);
                if ($result['code'] != 1) {
                    throw new Exception($result['msg']);
                }
                $list = $result['data']['list'];
                foreach ($list as &$item) {
                    $item['range'] = subtext($item['range'], 30);
                    $item['name'] = subtext($item['name'], 19);
                    if (session('memberToken')) {
                        $item['price'] = $item['price'] / 100;
                        if ($this->trade_money_ratio) {
                            $item['sale_price'] = number_format($item['price'] + round($item['price'] * ($this->trade_money_ratio / 100)));
                        } else {
                            $item['sale_price'] = number_format($item['price']);
                        }
                        $item['price'] = number_format($item['price']);
                    } else {
                        $item['price'] = '请登录后查看';
                        $item['sale_price'] = '请登录后查看';
                    }
                }
                $data = [
                    'current_page' => $page,
                    'data' => $list,
                    'last_page' => ceil($result['data']['total'] / 40),
                    'per_page' => 40,
                    'total' => $result['data']['total'],
                ];
            } catch (GuzzleException $e) {
                $this->error($e->getMessage());
            } catch (Exception $e) {
                $this->error($e->getMessage());
            }
            $this->success('返回成功',$data);
        }

        View::assign('trademarkData');
        return View::fetch('cbcrm@site/trade/trademark/index');
    }

    public function detail()
    {
        $id = $this->request->get('id',0,'intval')?:$this->error('参数错误');
        $row = null;
        $client = new Client();
        try {
            $params = [
                'api_key' => $this->api_key,
                'id' => $id,
            ];
            $response = $client->request('GET', $this->apiUrl . '/trade/trademark/getCloudDetail', [
                'query' => $params
            ]);
            $result = json_decode($response->getBody(), true);
            if ($result['code'] != 1) {
                throw new Exception($result['msg']);
            }
            $row = $result['data'];
            $row['price'] = $row['price'] / 100;
            if ($this->trade_money_ratio) {
                $row['sale_price'] = number_format($row['price'] + round($row['price'] * ($this->trade_money_ratio / 100)));
            } else {
                $row['sale_price'] = number_format($row['price']);
            }
            $row['price'] = number_format($row['price']);

        } catch (GuzzleException $e) {
            $this->error($e->getMessage());
        } catch (Exception $e) {
            $this->error($e->getMessage());
        }
        if (!$row || $row['status']!=1 || $row['admin_status']!=1 || $row['trade_status']!=0) {
            $this->error('商标未找到');
        }

        View::assign('row',$row);

        return View::fetch('cbcrm@site/trade/trademark/detail');
    }
}
