<?php


namespace app\cbcrm\controller\site;


use app\cbcrm\controller\BaseSite;
use app\cbcrm\model\customer\CustomerModel;
use app\cbcrm\model\goods\OrderModel;
use app\cbcrm\model\member\MemberModel;
use Ramsey\Uuid\Uuid;
use think\App;
use think\captcha\facade\Captcha;
use think\Exception;
use think\exception\ValidateException;
use think\facade\Db;
use think\facade\Log;
use think\facade\Validate;
use think\facade\View;

class User extends BaseSite
{
    public function __construct(App $app)
    {
        View::config(['layout_on' => true, 'layout_name' => 'site/common/user_layout']);
        View::assign('title','会员中心');
        parent::__construct($app);
    }

    public function index()
    {
        $userInfo = $this->auth();

        $userInfo->customer = (new CustomerModel())->where('user_id',$userInfo->id)->find();

        $userInfo->grade_name = Db::table('cb_crm_user_grade')->where('id', $userInfo->grade_id)->value('name');

        $where = [
            ['user_id','=',$userInfo->id],
            ['pay_status','=',1],
        ];

        $orderList = (new OrderModel())
            ->with(['goods'])
            ->where($where)
            ->order('create_time','desc')
            ->limit(0,3)
            ->select();
        foreach ($orderList as &$item) {
            foreach ($item->goods as &$goods) {
                $goods->goods_image = $goods->image?cdnurl($goods->image,true):'';
            }
        }


        View::assign('userInfo',$userInfo);

        View::assign('orderList',$orderList);

        return View::fetch('cbcrm@site/user/index');
    }

    public function profile()
    {
        $userInfo = $this->auth();

        $userInfo->grade_name = Db::table('cb_crm_user_grade')->where('id', $userInfo->grade_id)->value('name');

        View::assign('userInfo', $userInfo);

        return View::fetch('cbcrm@site/user/profile');
    }

    public function changepwd()
    {
        $userInfo = $this->auth();

        if ($this->request->isPost()) {
            $code = $this->request->post('code');
            $password = $this->request->post('password');
            $password_confirm = $this->request->post('password_confirm');
            if (!$code) {
                $this->error('请输入短信验证码');
            }
            if (!$password || !$password_confirm) {
                $this->error('请输入新密码');
            }
            if ($password != $password_confirm) {
                $this->error('确认密码不一致');
            }
            if (strlen($password) < 6 || strlen($password) > 36) {
                $this->error('密码长度/格式不正确');
            }
            $smsCode = Db::table('cb_crm_sms')
                ->where('event', 'changepwd')
                ->where('mobile', $userInfo['mobile'])
                ->where('code', $code)
                ->find();
            if (!$smsCode || $smsCode['times'] > 0 || strtotime('-5 min') > strtotime($smsCode['create_time'])) {
                $this->error('短信验证码错误或已失效');
            }

            $salt = random_build('alnum', 5);

            $new_password = md5(md5($password) . $salt);

            $data = [
                'password'=>$new_password,
                'salt'=>$salt,
                'update_time'=>date('Y-m-d H:i:s')
            ];

            $result = Db::table('cb_crm_user')->where('id', $userInfo->id)->update($data);

            // 删除验证码
            Db::table('cb_crm_sms')->where('id', $smsCode['id'])->delete();

            if ($result) {
                $this->success('修改成功');
            }else{
                $this->error('修改失败');
            }

        }

        View::assign('userInfo', $userInfo);

        return View::fetch('cbcrm@site/user/changepwd');
    }

    public function login()
    {
        //判断来源
        $url = $this->request->request('url','','strip_tags');
        if ($this->request->isPost()) {
            $type = $this->request->post('logo_type', 'mobile', 'strip_tags');
            if ($type == 'mobile') {
                $mobile = $this->request->post('mobile');
                $captcha = $this->request->post('captcha');
                $code = $this->request->post('code');
                try {
                    $this->validate([
                        'mobile' => $mobile,
                        'captcha' => $captcha,
                        'code' => $code
                    ], [
                        'mobile|手机号' => 'require|mobile',
                        'captcha|图形验证码' => 'require|captcha',
                        'code|短信验证码' => 'require|length:4',
                    ]);
                    $smsCode = Db::table('cb_crm_sms')
                        ->where('event', 'login')
                        ->where('mobile', $mobile)
                        ->where('code', $code)
                        ->find();
                    if (!$smsCode || $smsCode['times'] > 0 || strtotime('-5 min') > strtotime($smsCode['create_time'])) {
                        $this->error('短信验证码错误或已失效');
                    }

                } catch (ValidateException $e) {
                    // 验证失败 输出错误信息
                    $this->error($e->getMessage());
                }
                $userInfo = (new MemberModel())->where('mobile', $mobile)->find();
                if (!$userInfo) {
                    // 用户不存在则进行注册
                    $this->error('用户不存在');
                }
                // 删除验证码
                Db::table('cb_crm_sms')->where('id', $smsCode['id'])->delete();
            } elseif ($type == 'account') {
                $account = $this->request->post('account');
                $password = $this->request->post('password');
                try {
                    $this->validate([
                        'account' => $account,
                        'password' => $password,
                    ], [
                        'account|登录账号' => 'require|length:5,12',
                        'password|登录密码' => 'require|length:6,36',
                    ]);
                    $userInfo = (new MemberModel())->where('username|mobile', $account)->find();
                    if (!$userInfo) {
                        $this->error('账号或密码不正确');
                    }
                    if (md5(md5($password) . $userInfo->salt) != $userInfo->password) {
                        $this->error('账号或密码不正确');
                    }
                } catch (ValidateException $e) {
                    // 验证失败 输出错误信息
                    $this->error($e->getMessage());
                }
            }

            unset($userInfo->password, $userInfo->salt);
            $token = Uuid::uuid1();
            $expire_time = time() + $this->expire_time;
            Db::table('cb_crm_user_token')->insert(
                [
                    'user_id' => $userInfo->id,
                    'token' => "{$token}",
                    'expire_time' => $expire_time
                ]
            );
            Db::table('cb_crm_user')->where('id', $userInfo->id)->update(['last_login_time' => date('Y-m-d H:i:s')]);

            session('memberToken', "{$token}");
            session('memberInfo', $userInfo);
            $this->success('登录成功', ['url' =>$url?:'/cbcrm/member/index.html']);
        }
        $referer = $this->request->server('HTTP_REFERER', '', 'url_clean');
        if (!$url && $referer && !preg_match("/(user\/login|user\/register|user\/logout)/i", $referer)) {
            $url = $referer;
        }
        View::config(['layout_on' => false]);
        View::assign('wid', $this->wid);
        View::assign('url', $url);
        return View::fetch('cbcrm@site/user/login');
    }

    public function register()
    {
        if ($this->request->isPost()) {
            $mobile = $this->request->post('mobile');
            $password = $this->request->post('password');
            $captcha = $this->request->post('captcha');
            $code = $this->request->post('code');
            try {
                $this->validate([
                    'mobile' => $mobile,
                    'password' => $password,
                    'captcha' => $captcha,
                    'code' => $code
                ], [
                    'mobile|手机号' => 'require|mobile',
                    'password|登录密码' => 'require|length:6,36',
                    'captcha|图形验证码' => 'require|captcha',
                    'code|短信验证码' => 'require|length:4',
                ]);

                $check = Db::table('cb_crm_user')->where('mobile', $mobile)->value('id');
                if ($check) {
                    $this->error('该手机号已被注册');
                }

                $smsCode = Db::table('cb_crm_sms')
                    ->where('event', 'register')
                    ->where('mobile', $mobile)
                    ->where('code', $code)
                    ->find();
                if (!$smsCode || $smsCode['times'] > 0 || strtotime('-5 min') > strtotime($smsCode['create_time'])) {
                    $this->error('短信验证码错误或已失效');
                }

            } catch (ValidateException $e) {
                // 验证失败 输出错误信息
                $this->error($e->getMessage());
            }
            $result = false;
            $username = $mobile;
            Db::startTrans();
            try {
                $salt = random_build('alnum', 5);
                $data = [
                    'wid' => $this->wid,
                    'username' => $username,
                    'avatar' => import('static/img/avatar.png'),
                    'password' => md5(md5($password) . $salt),
                    'salt' => $salt,
                    'mobile' => $username,
                    'nickname' => substr_replace($username, '****', 3, 4),
                    'grade_id' => Db::table('cb_crm_user_grade')->where('wid', $this->wid)->order('weigh', 'asc')->value('id'),
                    'create_time' => date('Y-m-d H:i:s'),
                    'update_time' => date('Y-m-d H:i:s')
                ];
                $token = Uuid::uuid1();
                $expire_time = time() + $this->expire_time;

                $memberModel = new MemberModel();

                // 添加用户
                $user_id = $memberModel->insertGetId($data);

                // 创建一个客户信息
                (new CustomerModel())->registerCustomer(['user_id' => $user_id, 'nickname' => $data['nickname'], 'mobile' => $data['mobile']], $this->wid);

                $userInfo = $memberModel->where('id', $user_id)->find();
                // 删除验证码
                Db::table('cb_crm_sms')->where('id', $smsCode['id'])->delete();

                // 生成登录token
                Db::table('cb_crm_user_token')->insert(
                    [
                        'user_id' => $userInfo->id,
                        'token' => "{$token}",
                        'expire_time' => $expire_time
                    ]
                );

                Db::table('cb_crm_user')->where('id', $userInfo->id)->update(['last_login_time' => date('Y-m-d H:i:s')]);

                session('memberToken', "{$token}");
                session('memberInfo', $userInfo);
                $result = true;
                Db::commit();
            } catch (Exception $e) {
                Db::rollback();
                $this->error($e->getMessage());
            }
            if ($result === true) {
                $this->success('注册成功', ['url' => '/cbcrm/member/index']);
            }

        }
        View::config(['layout_on' => false]);
        View::assign('wid', $this->wid);
        return View::fetch('cbcrm@site/user/register');
    }

    public function logout(){

        session('memberToken', null);
        session('memberInfo', null);

        return redirect('/cbcrm/index');
    }
}
