<?php


namespace app\cbcrm\model\config;


use think\Collection;
use think\facade\Log;
use think\Model;

class SettingModel extends Model
{
    protected $table = 'cb_crm_setting';


    public function getDetail($group, $wid)
    {
        $list = (new Collection($this->where('group', $group)->where('wid', $wid)->select()));
        $config = array_merge_config($this->defaultData($group, $wid), $list->toArray());
        $data = [];
        foreach ($config as $item) {
            if (!is_array($item['value'])) {
                json_decode($item['value'], true);
                if (json_last_error() == JSON_ERROR_NONE) {
                    $item['value'] = json_decode($item['value'], true);
                }
            }
            $data[$item['name']] = is_numeric($item['value']) ? $item['value'] * 1 : $item['value'];
        }
        return $data;
    }

    public function insertOrUpdate($group, $params, $wid)
    {
        $hasConfig = $this->where('wid', $wid)->where('group', $group)->count();
        $data = [];
        if (!$hasConfig) {
            foreach ($params as $key => $value) {
                $data[] = [
                    'wid' => $wid,
                    'name' => $key,
                    'value' => $value
                ];
            }
            $insertData = array_merge_config($this->defaultData($group, $wid), $data);
            foreach ($insertData as $key => $datum) {
                $insertData[$key]['wid'] = $wid;
            }
            $result = $this->saveAll($insertData);
        } else {
            foreach ($params as $key => $value) {
                $data[] = [
                    'wid' => $wid,
                    'name' => $key,
                    'value' => $value
                ];
            }
            $updateData = array_merge_config($this->defaultData($group, $wid), $data);
            foreach ($updateData as $datum) {
                $has_id = $this->where('group', $group)->where('name', $datum['name'])->where('wid', $wid)->value('id');
                if ($has_id) {
                    $result = $this->where('id', $has_id)->update($datum);
                } else {
                    $datum['wid'] = $wid;
                    $result = $this->save($datum);
                }
            }
        }
        return $result;
    }

    // 获取单单某一项的配置值
    public function getConfigValue($group, $name, $wid)
    {
        $config = $this->where('group', $group)->where('name', $name)->where('wid', $wid)->value('value');
        if (!$config) {
            $groupData = $this->defaultData($group, $wid);
            $key = array_search($name, array_column($groupData, 'name'));
            $config = $groupData[$key]['value'];
        }
        if (!is_array($config)) {
            json_decode($config, true);
            if (json_last_error() == JSON_ERROR_NONE) {
                $config = json_decode($config, true);
            }
        }
        return $config;
    }

    // 获取某个配置组的值
    public function getConfigGroup($group, $wid)
    {
        $list = (new Collection($this->where('group', $group)->where('wid', $wid)->select()));
        $config = array_merge_config($this->defaultData($group, $wid), $list->toArray());
        $data = [];
        foreach ($config as $item) {
            if (!is_array($item['value'])) {
                json_decode($item['value'], true);
                if (json_last_error() == JSON_ERROR_NONE) {
                    $item['value'] = json_decode($item['value'], true);
                }
            }
            $data[$item['name']] = is_numeric($item['value']) ? $item['value'] * 1 : $item['value'];
        }
        return $data;
    }

    public function defaultData($group, $wid)
    {
        // 充值设置
        $recharge = [
            [
                'name' => 'is_open',
                'group' => 'recharge',
                'tip' => '是否开启会员充值',
                'value' => 1,
            ],
            [
                'name' => 'is_custom',
                'group' => 'recharge',
                'tip' => '充值自定义金额',
                'value' => 1,
            ],
            [
                'name' => 'lowest_money',
                'group' => 'recharge',
                'tip' => '最低充值金额',
                'value' => 10,
            ],
            [
                'name' => 'is_match_package',
                'group' => 'recharge',
                'tip' => '自动匹配套餐',
                'value' => 1,
            ],
            [
                'name' => 'remark',
                'group' => 'recharge',
                'tip' => '充值说明',
                'value' => '1. 账户充值仅限微信在线方式支付，充值金额实时到账；
2. 账户充值套餐赠送的金额即时到账；
3. 账户余额有效期：自充值日起至用完即止；
4. 若有其它疑问，可拨打客服电话400-000-1234',
            ]
        ];
        // 积分设置
        $score = [
            [
                'name' => 'is_shopping_gift',
                'group' => 'score',
                'tip' => '购物送积分',
                'value' => 0,
            ],
            [
                'name' => 'gift_ratio',
                'group' => 'score',
                'tip' => '积分赠送比例',
                'value' => 0,
            ],
            [
                'name' => 'remark',
                'group' => 'score',
                'tip' => '积分说明',
                'value' => "1.积分不可兑现、不可转让,仅可在本平台使用;\n" .
                    "2.您在本平台参加特定活动也可使用积分,详细使用规则以具体活动时的规则为准;\n" .
                    "3.积分的数值精确到个位(小数点后全部舍弃,不进行四舍五入)\n" .
                    "4.买家在完成该笔交易(订单状态为“已签收”)后才能得到此笔交易的相应积分,如购买商品参加店铺其他优惠,则优惠的金额部分不享受积分获取;",
            ],
            [
                'name' => 'is_shopping_discount',
                'group' => 'score',
                'tip' => '下单使用积分抵扣',
                'value' => 0,
            ],
            [
                'name' => 'discount_ratio',
                'group' => 'score',
                'tip' => '积分抵扣比例',
                'value' => 0,
            ],
            [
                'name' => 'full_order_price',
                'group' => 'score',
                'tip' => '订单满多少，最多可抵扣金额',
                'value' => 0,
            ],
            [
                'name' => 'max_money_ratio',
                'group' => 'score',
                'tip' => '最高可抵扣金额',
                'value' => 0,
            ],
        ];
        // 满额包邮
        $full_free = [
            [
                'name' => 'is_open',
                'group' => 'full_free',
                'tip' => '是否开启满额包邮',
                'value' => 0,
            ],
            [
                'name' => 'money',
                'group' => 'full_free',
                'tip' => '单笔订单满',
                'value' => 1,
            ],
            [
                'name' => 'excludedGoodsIds',
                'group' => 'full_free',
                'tip' => '不参与包邮的商品',
                'value' => [],
            ],
            [
                'name' => 'excludedRegions',
                'group' => 'full_free',
                'tip' => '不参与包邮的地区',
                'value' => [],
            ],
            [
                'name' => 'remark',
                'group' => 'full_free',
                'tip' => '满额包邮说明',
                'value' => '',
            ],
        ];
        // 微信配置
        $wechat = [
            [
                'name' => 'app_id',
                'group' => 'wechat',
                'tip' => '公众号APPID',
                'value' => ''
            ],
            [
                'name' => 'app_secret',
                'group' => 'wechat',
                'tip' => '公众号AppSecret',
                'value' => ''
            ],
            [
                'name' => 'miniapp_id',
                'group' => 'wechat',
                'tip' => '小程序APPID',
                'value' => ''
            ],
            [
                'name' => 'miniapp_secret',
                'group' => 'wechat',
                'tip' => '小程序AppSecret',
                'value' => ''
            ],
            [
                'name' => 'mch_id',
                'group' => 'wechat',
                'tip' => '微信商户号 MCHID',
                'value' => ''
            ],
            [
                'name' => 'api_key',
                'group' => 'wechat',
                'tip' => '微信支付密钥 APIKEY',
                'value' => ''
            ],
            [
                'name' => 'client_cert',
                'group' => 'wechat',
                'tip' => '证书文件cert',
                'value' => ''
            ],
            [
                'name' => 'cert_key',
                'group' => 'wechat',
                'tip' => '证书文件key',
                'value' => ''
            ]
        ];
        // 交易设置
        $trade = [
            [
                'name' => 'close_order',
                'group' => 'trade',
                'tip' => '未支付订单关闭时间',
                'value' => 0
            ],
            [
                'name' => 'receive_days',
                'group' => 'trade',
                'tip' => '订单自动收货天数',
                'value' => 0
            ],
            [
                'name' => 'refund_days',
                'group' => 'trade',
                'tip' => '允许申请售后天数',
                'value' => 0
            ],
            [
                'name' => 'freight_rule',
                'group' => 'trade',
                'tip' => '运费设置',
                'value' => '1'
            ],
            [
                'name' => 'trade_key',
                'group' => 'trade',
                'tip' => '商标云库key',
                'value' => ''
            ],
            [
                'name' => 'trade_money_ratio',
                'group' => 'trade',
                'tip' => '商标价格浮动比例',
                'value' => 0
            ],
        ];
        // 配送方式
        $delivery = [
            [
                'name' => 'delivery_type',
                'group' => 'delivery',
                'tip' => '配送方式',
                'value' => '1'
            ],
            [
                'name' => 'kuaidi100_customer',
                'group' => 'delivery',
                'tip' => '快递100 Customer',
                'value' => ''
            ],
            [
                'name' => 'kuaidi100_key',
                'group' => 'delivery',
                'tip' => '快递100 Key',
                'value' => ''
            ]
        ];
        // 商城设置
        $store = [
            [
                'name' => 'store_name',
                'group' => 'store',
                'tip' => '商城名称',
                'value' => ''
            ],
            [
                'name' => 'describe',
                'group' => 'store',
                'tip' => '商城简介',
                'value' => ''
            ],
            [
                'name' => 'store_tel',
                'group' => 'store',
                'tip' => '客服电话',
                'value' => ''
            ],
            [
                'name' => 'qq',
                'group' => 'store',
                'tip' => '客户QQ',
                'value' => ''
            ],
            [
                'name' => 'address',
                'group' => 'store',
                'tip' => '联系地址',
                'value' => ''
            ],
            [
                'name' => 'copyright',
                'group' => 'store',
                'tip' => '版权所有',
                'value' => ''
            ],
            [
                'name' => 'beian',
                'group' => 'store',
                'tip' => '备案号',
                'value' => ''
            ],
            [
                'name' => 'qrcode',
                'group' => 'store',
                'tip' => '微信二维码',
                'value' => ''
            ],
            [
                'name' => 'logo',
                'group' => 'store',
                'tip' => '商城logo',
                'value' => ''
            ],
            [
                'name' => 'cdnurl',
                'group' => 'store',
                'tip' => 'CDN',
                'value' => request()->domain() . '/storage/'
            ],
        ];
        // 短信配置
        $sms = [
            [
                'name' => 'engine',
                'group' => 'sms',
                'tip' => '短信平台',
                'value' => '{
                  "qcloud": {
                    "name": "腾讯云短信",
                    "website": "https://console.cloud.tencent.com/smsv2/app-manage",
                    "AppID": "",
                    "AppKey": "",
                    "sign": "超博CRM"
                  },
                  "aliyun": {
                    "name": "阿里云短信",
                    "website": "https://dysms.console.aliyun.com/dysms.htm",
                    "AccessKeyId": "",
                    "AccessKeySecret": "",
                    "sign": "超博CRM"
                  }
                }'
            ], [
                'name' => 'default',
                'group' => 'sms',
                'tip' => '默认平台',
                'value' => 'qcloud'
            ], [
                'name' => 'scene',
                'group' => 'sms',
                'tip' => '使用场景',
                'value' => '{
                  "captcha": {
                    "name": "短信验证码",
                    "isEnable": false,
                    "templateCode": "",
                    "content": "您的验证码为%s，该验证码5分钟内有效，请勿泄漏于他人！",
                    "variables": {
                      "qcloud": [
                        "{1}"
                      ],
                      "aliyun": [
                        "${code}"
                      ]
                    }
                  },
                  "order_pay": {
                    "name": "后台新订单",
                    "isEnable": false,
                    "templateCode": "",
                    "acceptPhone": "",
                    "content": "您有一条新订单，订单号为：%s，，请登录平台查看！回T退订",
                    "variables": {
                      "qcloud": [
                        "{1}"
                      ],
                      "aliyun": [
                        "${order_no}"
                      ]
                    }
                  }
                }'
            ]
        ];
        // H5端配置
        $h5 = [
            [
                'name' => 'enabled',
                'group' => 'h5',
                'tip' => '是否开启访问',
                'value' => 0
            ],
            [
                'name' => 'web_url',
                'group' => 'h5',
                'tip' => 'H5站点地址',
                'value' => request()->domain() . '/cbcrm/web/wid/' . $wid
            ]
        ];
        // PC端配置
        $pc = [
            [
                'name' => 'domain',
                'group' => 'pc',
                'tip' => '绑定域名',
                'value' => ''
            ],
            [
                'name' => 'site_name',
                'group' => 'pc',
                'tip' => '网站名称',
                'value' => ''
            ],
            [
                'name' => 'title',
                'group' => 'pc',
                'tip' => '首页标题',
                'value' => ''
            ],
            [
                'name' => 'keywords',
                'group' => 'pc',
                'tip' => '网站关键词',
                'value' => ''
            ],
            [
                'name' => 'description',
                'group' => 'pc',
                'tip' => '网站描述',
                'value' => ''
            ],
            [
                'name' => 'welcome',
                'group' => 'pc',
                'tip' => '欢迎词',
                'value' => ''
            ],
            [
                'name' => 'contact',
                'group' => 'pc',
                'tip' => '联系电话',
                'value' => ''
            ],
            [
                'name' => 'qq',
                'group' => 'pc',
                'tip' => '服务QQ',
                'value' => ''
            ],
            [
                'name' => 'address',
                'group' => 'pc',
                'tip' => '联系地址',
                'value' => ''
            ],
            [
                'name' => 'logo',
                'group' => 'pc',
                'tip' => '上传网站LOGO',
                'value' => ''
            ],
            [
                'name' => 'qrcode',
                'group' => 'pc',
                'tip' => '公众号二维码',
                'value' => ''
            ],
            [
                'name' => 'beian',
                'group' => 'pc',
                'tip' => '备案号',
                'value' => ''
            ],
            [
                'name' => 'copyright',
                'group' => 'pc',
                'tip' => '版权所有',
                'value' => ''
            ],
            [
                'name' => 'cdnurl',
                'group' => 'store',
                'tip' => 'CDN',
                'value' => request()->domain() . '/storage/'
            ]
        ];

        $data = [
            'recharge' => $recharge,
            'score' => $score,
            'full_free' => $full_free,
            'wechat' => $wechat,
            'trade' => $trade,
            'delivery' => $delivery,
            'store' => $store,
            'sms' => $sms,
            'h5' => $h5,
            'pc' => $pc,
        ];
        return $data[$group];
    }
}
